@@ -1,7 +1,7 @@
 /*
  * DMNTK - Decision Model and Notation Toolkit
  *
- * DMNTK common definitions.
+ * Common definitions
  *
  * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
  *
@@ -14,9 +14,23 @@
  * SOFTWARE.
  */
 
-//! DMNTK common definitions.
+//! Common definitions for components of Decision Model and Notation Toolkit.
+//!
+mod config;
+mod constants;
+mod errors;
+mod examples;
+mod feelify;
+mod href;
+mod jsonify;
+mod macros;
+mod stringify;
 
-pub mod errors;
-pub mod feelify;
-pub mod jsonify;
-pub mod macros;
+pub use config::{get_configuration, Configuration, ServerConfiguration};
+pub use constants::{DMNTK_COPYRIGHT, DMNTK_EXECUTABLE, DMNTK_NAME, DMNTK_VERSION};
+pub use errors::{DmntkError, Result};
+pub use examples::{EXAMPLE_0001_CTX, EXAMPLE_0001_DTB, EXAMPLE_0002_CTX, EXAMPLE_0002_DTB};
+pub use feelify::Feelify;
+pub use href::{HRef, OptHRef};
+pub use jsonify::Jsonify;
+pub use stringify::Stringify;
